@@ -10,20 +10,33 @@
     **/
 
 function squirrelmail_plugin_init_ldifimport() {
+
   global $squirrelmail_plugin_hooks;
 
   $squirrelmail_plugin_hooks['optpage_register_block']['ldifimport']
       = 'squirrelmail_ldifimport_optpage_register_block';
+
 }
 
+
 function squirrelmail_ldifimport_optpage_register_block() {
-  global $optpage_blocks;
 
-  $optpage_blocks[] = array(
-    'name' => _("LDIF Addressbook import"),
-    'url'  => '../plugins/ldifimport/ldifimport_opt.php',
-    'desc' => _("This option allows you to import an address book from another
-                 e-mail program such as NetScape Communicator or Eudora."),
-    'js'   => false
-  );
+
+  if (defined('SM_PATH'))
+     include_once(SM_PATH . 'plugins/ldifimport/functions.php');
+  else
+     include_once('../plugins/ldifimport/functions.php');
+
+  squirrelmail_ldifimport_optpage_register_block_do();
+
 }
+
+
+function ldifimport_version() {
+
+   return '1.3';
+
+}
+
+
+?>
